searchData={"items":[{"type":"module","title":"Dreamy","doc":"Dreamy provides useful macros, functions, types & operators to make elixir even dreamier 😴","ref":"Dreamy.html"},{"type":"macro","title":"Dreamy.>>>/2","doc":"Operator for Enum.map","ref":"Dreamy.html#%3E%3E%3E/2"},{"type":"macro","title":"Examples - Dreamy.>>>/2","doc":"```\niex> use Dreamy\n...> x = fn y -> y + 1 end\n...> y = fn z -> z * 2 end\n...> [1, 2]\n...> >>> x\n...> >>> y\n[4, 6]\n\niex> use Dreamy\n...> x = fn y -> y - 1 end\n...> [5, 7]\n...> >>> x\n...> >>> (&div(&1, 2))\n...> >>> x\n[1, 2]\n```","ref":"Dreamy.html#%3E%3E%3E/2-examples"},{"type":"macro","title":"Dreamy.const/2","doc":"Macro for defining a constant attribute and function","ref":"Dreamy.html#const/2"},{"type":"macro","title":"Examples - Dreamy.const/2","doc":"```\niex> use Dreamy\niex> const :example, \"XYZ\"\niex> @example\n\"XYZ\"\n\niex> example()\n\"XYZ\"\n```","ref":"Dreamy.html#const/2-examples"},{"type":"macro","title":"Dreamy.fallthrough/2","doc":"Macro for adding a default catchall -> clause to case statements, that returns the input value","ref":"Dreamy.html#fallthrough/2"},{"type":"macro","title":"Examples - Dreamy.fallthrough/2","doc":"```\niex> use Dreamy\n...> fallthrough {:error, \"error\"} do\n...> {:ok, v} -> v\n...> end\n{:error, \"error\"}\n\niex> use Dreamy\n...> fallthrough {:ok, \"OK\"} do\n...> {:ok, \"OK\"} -> \"OK\"\n...> end\n\"OK\"\n```","ref":"Dreamy.html#fallthrough/2-examples"},{"type":"macro","title":"Dreamy.or_else/2","doc":"Macro for adding a default catchall `true` clause to cond statements, that returns the default value","ref":"Dreamy.html#or_else/2"},{"type":"macro","title":"Examples - Dreamy.or_else/2","doc":"```\niex> use Dreamy\n...> x = 5\n...> or_else \"Less than 10\" do\n...> x == 10 -> \"10\"\n...> x > 10 -> \"Greater than 10\"\n...> end\n\"Less than 10\"\n\niex> use Dreamy\n...> x = 11\n...> or_else \"Less than 10\" do\n...> x == 10 -> \"10\"\n...> x > 10 -> \"Greater than 10\"\n...> end\n\"Greater than 10\"\n```","ref":"Dreamy.html#or_else/2-examples"},{"type":"macro","title":"Dreamy.otherwise/3","doc":"Macro for adding a default catchall -> clause to case statements, that returns the default value","ref":"Dreamy.html#otherwise/3"},{"type":"macro","title":"Examples - Dreamy.otherwise/3","doc":"```\niex> use Dreamy\n...> otherwise nil, {:error, :not_found} do\n...> {:ok, _} -> :ok\n...> end\n{:error, :not_found}\n\niex> use Dreamy\n...> otherwise {:ok, nil}, {:error, :not_found} do\n...> {:ok, _} -> :ok\n...> end\n:ok\n```","ref":"Dreamy.html#otherwise/3-examples"},{"type":"module","title":"Dreamy.Defaults","doc":"Helpers for dealing with Defaults for functions","ref":"Dreamy.Defaults.html"},{"type":"function","title":"Dreamy.Defaults.parse_bool/2","doc":"Function for extracting booleans from strings.\nUseful in configs","ref":"Dreamy.Defaults.html#parse_bool/2"},{"type":"function","title":"Options - Dreamy.Defaults.parse_bool/2","doc":"- default: (false) bool to be used when the value could not be parsed\n\n```\niex> use Dreamy\n...> parse_bool(\"TRUE\")\ntrue\n...> parse_bool(\"faLse\")\nfalse\n...> parse_bool(\"\", default: true)\ntrue\n...> parse_bool(nil, default: true)\ntrue\n```","ref":"Dreamy.Defaults.html#parse_bool/2-options"},{"type":"function","title":"Dreamy.Defaults.parse_defaults!/2","doc":"Function for extracting the default opts\nas provided and returns them in a variable sized tuple\nin defaults order\n\n```\niex> use Dreamy\n...> opts = [a: 1, b: 2]\n...> defaults = [a: -1, b: -2, c: -3]\n...> parse_defaults!(opts, defaults)\n{1, 2, -3}\n```","ref":"Dreamy.Defaults.html#parse_defaults!/2"},{"type":"function","title":"Dreamy.Defaults.parse_float/2","doc":"Function for extracting floats from strings.\nUseful in configs","ref":"Dreamy.Defaults.html#parse_float/2"},{"type":"function","title":"Options - Dreamy.Defaults.parse_float/2","doc":"- default: (0.0) float to be used when the value could not be parsed\n- remainder_allowed?: (false) wether or not to allow the float to be followed by an arbitrary string\n  - See Float.parse/1 for more info\n\n```\niex> use Dreamy\n...> parse_float(\"3.14\")\n3.14\n```\n```\niex> use Dreamy\n...> parse_float(\"1.23abc\", remainder_allowed?: true, default: 0.1)\n1.23\n```\n```\niex> use Dreamy\n...> parse_float(\"123abc\", remainder_allowed?: false, default: 0.1)\n0.1\n```","ref":"Dreamy.Defaults.html#parse_float/2-options"},{"type":"function","title":"Dreamy.Defaults.parse_int/2","doc":"Function for extracting integers from strings.\nUseful in configs","ref":"Dreamy.Defaults.html#parse_int/2"},{"type":"function","title":"Options - Dreamy.Defaults.parse_int/2","doc":"- default: (0) int to be used when the value could not be parsed\n- base: (10) base to parse the integer as\n- remainder_allowed?: (false) wether or not to allow the integer to be followed by an arbitrary string\n  - See Integer.parse/2 for more info\n\n```\niex> use Dreamy\n...> parse_int(\"123\")\n123\n```\n```\niex> use Dreamy\n...> parse_int(\"deadbeef\", base: 16)\n3735928559\n```\n```\niex> use Dreamy\n...> parse_int(\"123abc\", remainder_allowed?: true, default: -1)\n123\n```\n```\niex> use Dreamy\n...> parse_int(\"123abc\", remainder_allowed?: false, default: -1)\n-1\n```","ref":"Dreamy.Defaults.html#parse_int/2-options"},{"type":"module","title":"Dreamy.Either","doc":"Datatype for representing Either, Or","ref":"Dreamy.Either.html"},{"type":"function","title":"Dreamy.Either.either/2","doc":"Returns an Either tuple","ref":"Dreamy.Either.html#either/2"},{"type":"function","title":"Examples - Dreamy.Either.either/2","doc":"```\nuse Dreamy\niex> either(:l, :r)\n{Dreamy.Either, :l, :r}\n```","ref":"Dreamy.Either.html#either/2-examples"},{"type":"function","title":"Dreamy.Either.flat_map_left/2","doc":"Applies the function to the left value and flattens","ref":"Dreamy.Either.html#flat_map_left/2"},{"type":"function","title":"Examples - Dreamy.Either.flat_map_left/2","doc":"```\nuse Dreamy\niex> either(:l, :r)\n...> |> flat_map_left(fn _ -> left(:new_left) end)\n{Dreamy.Either, :new_left, :r}\n```","ref":"Dreamy.Either.html#flat_map_left/2-examples"},{"type":"function","title":"Dreamy.Either.flat_map_right/2","doc":"Applies the function to the right value and flattens","ref":"Dreamy.Either.html#flat_map_right/2"},{"type":"function","title":"Examples - Dreamy.Either.flat_map_right/2","doc":"```\nuse Dreamy\niex> either(:l, :r)\n...> |> flat_map_right(fn _ -> right(:new_right) end)\n{Dreamy.Either, :l, :new_right}\n```","ref":"Dreamy.Either.html#flat_map_right/2-examples"},{"type":"function","title":"Dreamy.Either.get_left/1","doc":"Returns the left value from an Either tuple","ref":"Dreamy.Either.html#get_left/1"},{"type":"function","title":"Examples - Dreamy.Either.get_left/1","doc":"```\nuse Dreamy\niex> either(:l, :r)\n...> |> get_left()\n:l\n```","ref":"Dreamy.Either.html#get_left/1-examples"},{"type":"function","title":"Dreamy.Either.get_right/1","doc":"Returns the right value from an Either tuple","ref":"Dreamy.Either.html#get_right/1"},{"type":"function","title":"Examples - Dreamy.Either.get_right/1","doc":"```\nuse Dreamy\niex> either(:l, :r)\n...> |> get_right()\n:r\n```","ref":"Dreamy.Either.html#get_right/1-examples"},{"type":"macro","title":"Dreamy.Either.is_either/1","doc":"","ref":"Dreamy.Either.html#is_either/1"},{"type":"macro","title":"Dreamy.Either.is_left/1","doc":"","ref":"Dreamy.Either.html#is_left/1"},{"type":"macro","title":"Dreamy.Either.is_right/1","doc":"","ref":"Dreamy.Either.html#is_right/1"},{"type":"function","title":"Dreamy.Either.left/1","doc":"Returns an Either tuple with left value populated, and the right nil","ref":"Dreamy.Either.html#left/1"},{"type":"function","title":"Examples - Dreamy.Either.left/1","doc":"```\nuse Dreamy\niex> left(:l)\n{Dreamy.Either, :l, nil}\n```","ref":"Dreamy.Either.html#left/1-examples"},{"type":"function","title":"Dreamy.Either.map_left/2","doc":"Applies the function to the left value","ref":"Dreamy.Either.html#map_left/2"},{"type":"function","title":"Examples - Dreamy.Either.map_left/2","doc":"```\nuse Dreamy\niex> either(:l, :r)\n...> |> map_left(&Atom.to_string/1)\n{Dreamy.Either, \"l\", :r}\n```","ref":"Dreamy.Either.html#map_left/2-examples"},{"type":"function","title":"Dreamy.Either.map_right/2","doc":"Applies the function to the right value","ref":"Dreamy.Either.html#map_right/2"},{"type":"function","title":"Examples - Dreamy.Either.map_right/2","doc":"```\nuse Dreamy\niex> either(:l, :r)\n...> |> map_right(&Atom.to_string/1)\n{Dreamy.Either, :l, \"r\"}\n```","ref":"Dreamy.Either.html#map_right/2-examples"},{"type":"function","title":"Dreamy.Either.right/1","doc":"Returns an Either tuple with right value populated, and the left nil","ref":"Dreamy.Either.html#right/1"},{"type":"function","title":"Examples - Dreamy.Either.right/1","doc":"```\nuse Dreamy\niex> right(:r)\n{Dreamy.Either, nil, :r}\n```","ref":"Dreamy.Either.html#right/1-examples"},{"type":"type","title":"Dreamy.Either.left/2","doc":"","ref":"Dreamy.Either.html#t:left/2"},{"type":"type","title":"Dreamy.Either.right/2","doc":"","ref":"Dreamy.Either.html#t:right/2"},{"type":"type","title":"Dreamy.Either.t/2","doc":"Monodic type representing a left or right tuple","ref":"Dreamy.Either.html#t:t/2"},{"type":"module","title":"Dreamy.Monodic","doc":"Functions for use with both Result and Option monads","ref":"Dreamy.Monodic.html"},{"type":"function","title":"Dreamy.Monodic.flat_map/2","doc":"Alias for ~>>","ref":"Dreamy.Monodic.html#flat_map/2"},{"type":"function","title":"Dreamy.Monodic.flatten/1","doc":"Function that flattens monads containing other monads","ref":"Dreamy.Monodic.html#flatten/1"},{"type":"function","title":"Result Examples - Dreamy.Monodic.flatten/1","doc":"```\niex> use Dreamy\n...> flatten(ok(ok(\"Hello World\")))\n{:ok, \"Hello World\"}\n\niex> use Dreamy\n...> flatten(ok(error(\"Hello World\")))\n{:error, \"Hello World\"}\n\niex> use Dreamy\n...> flatten(error(ok(\"Hello World\")))\n{:ok, \"Hello World\"}\n\niex> use Dreamy\n...> flatten(error(error(\"Hello World\")))\n{:error, \"Hello World\"}\n```","ref":"Dreamy.Monodic.html#flatten/1-result-examples"},{"type":"function","title":"Option Examples - Dreamy.Monodic.flatten/1","doc":"```\niex> use Dreamy\n...> flatten(option(option(\"Hello World\")))\n{Option, \"Hello World\"}\n\niex> use Dreamy\n...> flatten(option(empty()))\n{Option, :empty}\n```","ref":"Dreamy.Monodic.html#flatten/1-option-examples"},{"type":"function","title":"Either Examples - Dreamy.Monodic.flatten/1","doc":"```\niex> use Dreamy\n...> flatten(left(right(\"Hello World\")))\n{Either, nil, \"Hello World\"}\n\niex> use Dreamy\n...> flatten(right(left(\"Hello World\")))\n{Either, \"Hello World\", nil}\n```","ref":"Dreamy.Monodic.html#flatten/1-either-examples"},{"type":"macro","title":"Dreamy.Monodic.is_monodic/1","doc":"","ref":"Dreamy.Monodic.html#is_monodic/1"},{"type":"function","title":"Dreamy.Monodic.map/2","doc":"Alias for ~>/2","ref":"Dreamy.Monodic.html#map/2"},{"type":"function","title":"Dreamy.Monodic.~>/2","doc":"Function for applying result tuples & options on success only","ref":"Dreamy.Monodic.html#~%3E/2"},{"type":"function","title":"Result Examples - Dreamy.Monodic.~>/2","doc":"```\niex> use Dreamy\n...> {:ok, 1}\n...> ~> fn x -> {:ok, x + 1} end\n...> ~> fn y -> y + 1 end\n3\n\niex> use Dreamy\n...> {:error, 1}\n...> ~> fn x -> x + 1 end\n{:error, 1}\n```","ref":"Dreamy.Monodic.html#~%3E/2-result-examples"},{"type":"function","title":"Option Examples - Dreamy.Monodic.~>/2","doc":"```\niex> use Dreamy\n...> empty()\n...> ~> (fn _ -> :ok end)\n{Dreamy.Option, :empty}\n\niex> use Dreamy\n...> option(1)\n...> ~> (fn x -> x + 1 end)\n{Dreamy.Option, 2}","ref":"Dreamy.Monodic.html#~%3E/2-option-examples"},{"type":"function","title":"Either Examples - Dreamy.Monodic.~>/2","doc":"```\niex> use Dreamy\n...> either(:l, :r)\n...> ~> &Atom.to_string/1\n{Dreamy.Either, \"l\", :r}\n\niex> use Dreamy\n...> either(100, -1)\n...> ~> (fn l -> l + 1 end)\n{Dreamy.Either, 101, -1}\n```","ref":"Dreamy.Monodic.html#~%3E/2-either-examples"},{"type":"function","title":"Dreamy.Monodic.~>>/2","doc":"Function for applying result tuples & options on success only","ref":"Dreamy.Monodic.html#~%3E%3E/2"},{"type":"function","title":"Result Examples - Dreamy.Monodic.~>>/2","doc":"```\niex> use Dreamy\n...> {:ok, 1}\n...> ~>> fn x -> {:ok, x + 1} end\n...> ~>> fn x -> {:ok, x * 2} end\n{:ok, 4}\n\niex> use Dreamy\n...> {:error, 1}\n...> ~>> fn {:ok, x} -> {:ok, x + 1} end\n{:error, 1}\n```","ref":"Dreamy.Monodic.html#~%3E%3E/2-result-examples"},{"type":"function","title":"Option Examples - Dreamy.Monodic.~>>/2","doc":"```\niex> use Dreamy\n...> empty()\n...> ~>> (fn x -> option(x + 2) end)\n{Dreamy.Option, :empty}\n\niex> use Dreamy\n...> option(1)\n...> ~>> (fn x -> option(x + 2) end)\n{Dreamy.Option, 3}\n```","ref":"Dreamy.Monodic.html#~%3E%3E/2-option-examples"},{"type":"module","title":"Dreamy.Option","doc":"Functions for use with Options","ref":"Dreamy.Option.html"},{"type":"function","title":"Dreamy.Option.empty/0","doc":"","ref":"Dreamy.Option.html#empty/0"},{"type":"function","title":"Dreamy.Option.from_result/1","doc":"Build an Option from a Result","ref":"Dreamy.Option.html#from_result/1"},{"type":"function","title":"Examples - Dreamy.Option.from_result/1","doc":"```\niex> use Dreamy\n...> from_result({:error, \"err\"})\n{Dreamy.Option, :empty}\n\niex> use Dreamy\n...> from_result({:ok, \"OK\"})\n{Dreamy.Option, \"OK\"}\n```","ref":"Dreamy.Option.html#from_result/1-examples"},{"type":"function","title":"Dreamy.Option.get/1","doc":"Get the value of an option","ref":"Dreamy.Option.html#get/1"},{"type":"function","title":"Examples - Dreamy.Option.get/1","doc":"```\niex> use Dreamy\n...> empty()\n...> |> get()\n:error\n\niex> use Dreamy\n...> option(\"Hello World\")\n...> |> get()\n{:ok, \"Hello World\"}\n```","ref":"Dreamy.Option.html#get/1-examples"},{"type":"function","title":"Dreamy.Option.get!/1","doc":"Get the value of an option, throwing an error if empty","ref":"Dreamy.Option.html#get!/1"},{"type":"function","title":"Examples - Dreamy.Option.get!/1","doc":"```\niex> use Dreamy\n...> empty()\n...> |> get!()\n** (RuntimeError) Empty Option\n\niex> use Dreamy\n...> option(\"Hello World\")\n...> |> get!()\n\"Hello World\"\n```","ref":"Dreamy.Option.html#get!/1-examples"},{"type":"macro","title":"Dreamy.Option.is_empty/1","doc":"","ref":"Dreamy.Option.html#is_empty/1"},{"type":"macro","title":"Dreamy.Option.is_option/1","doc":"Returns an empty Option","ref":"Dreamy.Option.html#is_option/1"},{"type":"macro","title":"Examples - Dreamy.Option.is_option/1","doc":"```\niex> use Dreamy\n...> empty()\n{Dreamy.Option, :empty}\n```","ref":"Dreamy.Option.html#is_option/1-examples"},{"type":"function","title":"Dreamy.Option.option/1","doc":"builds an Option from a value","ref":"Dreamy.Option.html#option/1"},{"type":"function","title":"Examples - Dreamy.Option.option/1","doc":"```\niex> use Dreamy\n...> option(nil)\n{Dreamy.Option, :empty}\n\niex> use Dreamy\n...> empty() == option(nil)\ntrue\n\niex> use Dreamy\n...> option(\"Hello World\")\n{Dreamy.Option, \"Hello World\"}\n```","ref":"Dreamy.Option.html#option/1-examples"},{"type":"function","title":"Dreamy.Option.to_result/1","doc":"Build an Result from an Option","ref":"Dreamy.Option.html#to_result/1"},{"type":"function","title":"Examples - Dreamy.Option.to_result/1","doc":"```\niex> use Dreamy\n...> empty()\n...> |> to_result()\n{:error, nil}\n\niex> use Dreamy\n...> option(\"OK\")\n...> |> to_result()\n{:ok, \"OK\"}\n```","ref":"Dreamy.Option.html#to_result/1-examples"},{"type":"type","title":"Dreamy.Option.t/1","doc":"","ref":"Dreamy.Option.html#t:t/1"},{"type":"module","title":"Dreamy.Result","doc":"Functions for use with :ok, and :error tuples","ref":"Dreamy.Result.html"},{"type":"function","title":"Dreamy.Result.error/1","doc":"Returns an error Result","ref":"Dreamy.Result.html#error/1"},{"type":"function","title":"Examples - Dreamy.Result.error/1","doc":"```\niex> use Dreamy\n...> error(\"err\")\n{:error, \"err\"}\n```","ref":"Dreamy.Result.html#error/1-examples"},{"type":"function","title":"Dreamy.Result.flip/1","doc":"Function for flipping results","ref":"Dreamy.Result.html#flip/1"},{"type":"function","title":"Examples - Dreamy.Result.flip/1","doc":"```\niex> use Dreamy\n...> flip({:ok, 3})\n{:error, 3}\n\niex> use Dreamy\n...> flip({:error, 3})\n{:ok, 3}\n```","ref":"Dreamy.Result.html#flip/1-examples"},{"type":"function","title":"Dreamy.Result.from_option/1","doc":"Build an Result from an Option","ref":"Dreamy.Result.html#from_option/1"},{"type":"function","title":"Examples - Dreamy.Result.from_option/1","doc":"```\niex> use Dreamy\n...> empty()\n...> |> from_option()\n{:error, nil}\n\niex> use Dreamy\n...> option(\"OK\")\n...> |> from_option()\n{:ok, \"OK\"}\n```","ref":"Dreamy.Result.html#from_option/1-examples"},{"type":"macro","title":"Dreamy.Result.is_error/1","doc":"","ref":"Dreamy.Result.html#is_error/1"},{"type":"macro","title":"Dreamy.Result.is_ok/1","doc":"","ref":"Dreamy.Result.html#is_ok/1"},{"type":"macro","title":"Dreamy.Result.is_result/1","doc":"","ref":"Dreamy.Result.html#is_result/1"},{"type":"function","title":"Dreamy.Result.ok/1","doc":"Returns an empty Option","ref":"Dreamy.Result.html#ok/1"},{"type":"function","title":"Examples - Dreamy.Result.ok/1","doc":"```\niex> use Dreamy\n...> ok(\"Hello World\")\n{:ok, \"Hello World\"}\n```","ref":"Dreamy.Result.html#ok/1-examples"},{"type":"function","title":"Dreamy.Result.to_option/1","doc":"Function to convert results to options","ref":"Dreamy.Result.html#to_option/1"},{"type":"function","title":"Examples - Dreamy.Result.to_option/1","doc":"```\niex> use Dreamy\n...> to_option({:ok, 3})\n{Dreamy.Option, 3}\n\niex> use Dreamy\n...> to_option({:error, 3})\n{Dreamy.Option, :empty}\n```","ref":"Dreamy.Result.html#to_option/1-examples"},{"type":"function","title":"Dreamy.Result.unwrap/1","doc":"Function for extracting values from :ok records","ref":"Dreamy.Result.html#unwrap/1"},{"type":"function","title":"Examples - Dreamy.Result.unwrap/1","doc":"```\niex> use Dreamy\n...> {:ok, \"hello\"}\n...> |> unwrap\n\"hello\"\n\niex> use Dreamy\n...> {:error, \"world\"}\n...> |> unwrap\n{:error, \"world\"}\n```","ref":"Dreamy.Result.html#unwrap/1-examples"},{"type":"function","title":"Dreamy.Result.unwrap_error/1","doc":"Function for extracting values from :error tuples","ref":"Dreamy.Result.html#unwrap_error/1"},{"type":"function","title":"Examples - Dreamy.Result.unwrap_error/1","doc":"```\niex> use Dreamy\n...> {:ok, \"hello\"}\n...> |> unwrap_error\n{:ok, \"hello\"}\n\niex> use Dreamy\n...> {:error, \"world\"}\n...> |> unwrap_error\n\"world\"\n```","ref":"Dreamy.Result.html#unwrap_error/1-examples"},{"type":"function","title":"Dreamy.Result.|||/2","doc":"Function getting the first :ok result if one exists","ref":"Dreamy.Result.html#%7C%7C%7C/2"},{"type":"function","title":"Examples - Dreamy.Result.|||/2","doc":"```\niex> use Dreamy\n...> {:ok, \"success\"} ||| {:ok, \"success 2\"}\n{:ok, \"success\"}\n\niex> use Dreamy\n...> {:error, \"oops\"} ||| {:ok, \"success 2\"}\n{:ok, \"success 2\"}\n\niex> use Dreamy\n...> {:error, \"oops\"} ||| {:error, \"darn\"}\n{:error, \"oops\"}\n\niex> use Dreamy\n...> {:ok, \"first try\"} ||| {:error, \"darn\"} ||| {:ok, \"finally\"}\n{:ok, \"first try\"}\n\niex> use Dreamy\n...> {:error, \"oops\"} ||| {:error, \"darn\"} ||| {:ok, \"finally\"}\n{:ok, \"finally\"}\n```","ref":"Dreamy.Result.html#%7C%7C%7C/2-examples"},{"type":"type","title":"Dreamy.Result.t/2","doc":"Wrapper for :ok, and :error tuple","ref":"Dreamy.Result.html#t:t/2"},{"type":"module","title":"Dreamy.Types","doc":"Useful Type definitions","ref":"Dreamy.Types.html"},{"type":"type","title":"Dreamy.Types.either/2","doc":"Monodic type representing a left or right tuple","ref":"Dreamy.Types.html#t:either/2"},{"type":"type","title":"Dreamy.Types.enumerable/1","doc":"Type for documenting the value within an enumerable","ref":"Dreamy.Types.html#t:enumerable/1"},{"type":"type","title":"Dreamy.Types.nullable/1","doc":"Type union of `t` & `nil`","ref":"Dreamy.Types.html#t:nullable/1"},{"type":"type","title":"Dreamy.Types.option/1","doc":"Monodic type that can hold a value","ref":"Dreamy.Types.html#t:option/1"},{"type":"type","title":"Dreamy.Types.result/2","doc":"Monodic type for :ok, :error tuples","ref":"Dreamy.Types.html#t:result/2"},{"type":"extras","title":"Dreamy 😴","doc":"# Dreamy 😴\n\n[![ci](https://github.com/bwireman/dreamy/actions/workflows/elixir.yml/badge.svg?branch=main)](https://github.com/bwireman/dreamy/actions/workflows/elixir.yml)\n[![mit](https://img.shields.io/github/license/bwireman/dreamy?color=brightgreen)](https://github.com/bwireman/dreamy/blob/main/LICENSE)\n[![commits](https://img.shields.io/github/last-commit/bwireman/dreamy)](https://github.com/bwireman/dreamy/commit/main)\n[![0.2.3](https://img.shields.io/hexpm/v/dreamy?color=brightgreen&style=flat)](https://hexdocs.pm/dreamy/readme.html)\n[![downloads](https://img.shields.io/hexpm/dt/dreamy?color=brightgreen)](https://hex.pm/packages/dreamy/)\n[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen)](http://makeapullrequest.com)\n![Dreamy 😴](https://img.shields.io/badge/Dreamy%20%F0%9F%98%B4-blue)\n\nDreamy provides useful macros, functions, types & operators to make elixir even dreamier 😴\n\n- 📔 Docs: https://hexdocs.pm/dreamy/readme.html\n- 💾 download: https://hex.pm/packages/dreamy","ref":"readme.html"},{"type":"extras","title":"Modules - Dreamy 😴","doc":"- [`Dreamy`](https://hexdocs.pm/dreamy/Dreamy.html): Dreamy provides useful macros, functions, types & operators to make elixir even dreamier 😴\n- [`Dreamy.Defaults`](https://hexdocs.pm/dreamy/Dreamy.Defaults.html): Helpers for dealing with Defaults for functions\n- [`Dreamy.Either`](https://hexdocs.pm/dreamy/Dreamy.Either.html): Datatype for representing Either, Or\n- [`Dreamy.Monodic`](https://hexdocs.pm/dreamy/Dreamy.Monodic.html): Functions for use with both Result and Option monads\n- [`Dreamy.Option`](https://hexdocs.pm/dreamy/Dreamy.Option.html): Functions for use with Options\n- [`Dreamy.Result`](https://hexdocs.pm/dreamy/Dreamy.Result.html): Functions for use with :ok, and :error tuples\n- [`Dreamy.Types`](https://hexdocs.pm/dreamy/Dreamy.Types.html): Useful Type definitions","ref":"readme.html#modules"},{"type":"extras","title":"Usage - Dreamy 😴","doc":"```elixir\ndefmodule Example.Usage do\n  use Dreamy\n\n  # read file and split into a map of software => version,\n  # -> %{\"elixir\" => \"x.x.x\", \"erlang\" => \"x.x.x\"}\n  @spec versions() :: map()\n  def versions do\n    File.read!(\".tool-versions\")\n    |> String.split(\"\\n\", parts: 2)\n    >>> (&String.trim/1)\n    >>> (&String.split/1)\n    >>> (&List.to_tuple/1)\n    |> Enum.into(%{})\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Dreamy 😴","doc":"[Available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `dreamy` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:dreamy, \"~> 0.2.3\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown"}